@@ -1,11 +1,9 @@
-#!/usr/bin/env perl
 use Mojolicious::Lite;
-use lib '../lib';
 use Mojito;
 use Mojito::Auth;
 use Plack::Builder;
-use Data::Dumper::Concise;
 use JSON;
+use Data::Dumper::Concise;
 
 # Make a shortcut the the mojito app object
 app->helper(
@@ -109,6 +107,14 @@ get '/collection/:id' => sub {
     $self->render( text => $self->mojito->collection_page($params) );
 };
 
+get '/public/collection/:id' => sub {
+    my ($self) = (shift);
+    my $params;
+    $params->{id} = $self->param('id');
+    $params->{public} = 1;
+    $self->render( text => $self->mojito->collection_page($params) );
+};
+
 get '/collections' => sub {
     my ($self) = (shift);
     $self->render( text => $self->mojito->collections_index );
@@ -128,6 +134,56 @@ post '/collection/:id/sort' => sub {
     $self->redirect_to($self->mojito->sort_collection($params));
 };
 
+get '/collection/:collection_id/page/:page_id' => sub {
+    my ($self) = @_;
+
+    my $params =  {
+        collection_id => $self->param('collection_id'),
+        page_id       => $self->param('page_id'),
+    };
+    my $output = $self->mojito->view_page_collected($params);
+
+    $self->render(text => $output);
+};
+
+get '/public/collection/:collection_id/page/:page_id' => sub {
+    my $self = shift;
+
+    my $params =  {
+        public        => 1,
+        collection_id => $self->param('collection_id'),
+        page_id       => $self->param('page_id'), 
+   };
+   my $output = $self->mojito->view_page_collected($params);
+    
+   $self->render(text => $output);
+};
+
+get  '/collection/:collection_id/merge' => sub {
+    my $self = shift;
+    my $params = {
+        collection_id => $self->param('collection_id'),
+    };
+    my $output = $self->mojito->merge_collection($params);
+    $self->render(text => $output);
+};
+
+get '/collection/:collection_id/delete' => sub {
+    my ($self) = shift;
+    my $redirect_url = $self->mojito->delete_collection({ collection_id => $self->param('collection_id') });
+    $self->redirect_to($redirect_url);
+};
+
+get '/collection/:collection_id/epub' => sub {
+    my ($self) = (shift);
+    
+    my $collection_id = $self->param('collection_id');
+    my $output = $self->mojito->epub_collection({ collection_id => $self->param('collection_id') });
+    $self->res->headers->add( 'Content-type' => 'application/octet-stream');
+    $self->res->headers->add( 'Content-Disposition' => "attachment; filename=collection_${collection_id}.epub" );
+    $self->render(data => $output);
+};
+
 post '/publish' => sub {
     my ($self) = (shift);
     $self->render( json => $self->mojito->publish_page($self->req->params->to_hash) );
@@ -158,3 +214,4 @@ builder {
 
     app->start;
 };
+
